package main

import (
	"flag"
	"fmt"

	"tianyuan-api/apps/sentinel/internal/config"
	productServer "tianyuan-api/apps/sentinel/internal/server/product"
	secretServer "tianyuan-api/apps/sentinel/internal/server/secret"
	userproductServer "tianyuan-api/apps/sentinel/internal/server/userproduct"
	whitelistServer "tianyuan-api/apps/sentinel/internal/server/whitelist"
	"tianyuan-api/apps/sentinel/internal/svc"
	"tianyuan-api/apps/sentinel/sentinel"

	"github.com/zeromicro/go-zero/core/conf"
	"github.com/zeromicro/go-zero/core/service"
	"github.com/zeromicro/go-zero/zrpc"
	"google.golang.org/grpc"
	"google.golang.org/grpc/reflection"
)

var configFile = flag.String("f", "etc/sentinel.yaml", "the config file")

func main() {
	flag.Parse()

	var c config.Config
	conf.MustLoad(*configFile, &c)
	ctx := svc.NewServiceContext(c)

	s := zrpc.MustNewServer(c.RpcServerConf, func(grpcServer *grpc.Server) {
		sentinel.RegisterWhitelistServer(grpcServer, whitelistServer.NewWhitelistServer(ctx))
		sentinel.RegisterSecretServer(grpcServer, secretServer.NewSecretServer(ctx))
		sentinel.RegisterProductServer(grpcServer, productServer.NewProductServer(ctx))
		sentinel.RegisterUserProductServer(grpcServer, userproductServer.NewUserProductServer(ctx))

		if c.Mode == service.DevMode || c.Mode == service.TestMode {
			reflection.Register(grpcServer)
		}
	})
	defer s.Stop()

	fmt.Printf("Starting rpc server at %s...\n", c.ListenOn)
	s.Start()
}
